@@ -7,20 +7,9 @@ import re
 import uuid
 from asyncio import Future
 from typing import Awaitable, Optional, Union
-import ddtrace
 
 from simple_api_framework.monitors import DataDogMonitor
 
-if os.getenv("DD_SERVICE") and os.getenv("DD_API_KEY") and os.getenv("DD_API_KEY") and os.getenv("DD_ENV"):
-    ddtrace.patch(tornado=True)
-    ddtrace.patch(logging=True)
-    if os.getenv("REDIS_URL"):
-        ddtrace.patch(aioredis=True)
-    if os.getenv("MONGODB_URL"):
-        ddtrace.patch(mongoengine=True)
-    if os.getenv("DB_URL"):
-        ddtrace.patch(aiopg=True)
-
 import dotenv
 import magic
 import sentry_sdk
